package id

import "fmt"

const (
	Field        = "field"
	FieldsPrefix = "fields"
)

type FieldId struct {
	ItemId
	Field string `json:"field,omitempty" bson:"field,omitempty"`
}

var _ Descriptor = &FieldId{}

func (id *FieldId) New() Descriptor {
	return &FieldId{}
}

func (id *FieldId) Type() string { return Field }

func (id *FieldId) String() string {
	return Join(id.ItemId.String(), FieldsPrefix, id.Field)

}

func (id *FieldId) FromParts(parts []string) error {
	if len(parts) != 10 || parts[8] != FieldsPrefix {
		return ErrInvalidID
	}
	if err := id.ItemId.FromParts(parts[:8]); err != nil {
		return err
	}
	id.Field = parts[9]
	return nil
}

func (id *FieldId) Map() map[string]any {
	m := id.ItemId.Map()
	m["field"] = id.Field
	m["type"] = Field
	return m
}

func (id *FieldId) FromMap(m map[string]any) error {
	id.Field = m["field"].(string)
	if id.Field == "" {
		return fmt.Errorf("%w: Field required", ErrInvalidID)
	}

	if err := id.ItemId.FromMap(m); err != nil {
		return err
	}
	return nil
}

func (id *FieldId) Validate() error {
	if id.Field == "" {
		return fmt.Errorf("%w: Field required", ErrInvalidID)
	}

	return id.ItemId.Validate()
}

func NewFieldId(spaceID, envID, collID, itemID, id string) *ObjectId {
	return &ObjectId{Descriptor: &FieldId{
		ItemId: ItemId{
			CollectionId: CollectionId{
				EnvironmentId: EnvironmentId{
					SpaceId: SpaceId{
						SpaceID: spaceID,
					},
					EnvironmentID: envID,
				},
				CollectionID: collID,
			},
			ItemID: itemID,
		},
		Field: id,
	}}
}
